@@ -433,22 +433,6 @@ static void check_x_events(void)
 		    break;
 	       }
 	  }
-	  else if (WINDOW && ev.xany.window == WINDOW)
-	  {
-	       switch (ev.type)
-	       {
-	       case ConfigureRequest:
-		    /* The application has modified its window. */
-		    D("ConfigureRequest\n");
-		    set_aspect(ev.xconfigure.width, ev.xconfigure.height);
-		    adjust_window_size();
-		    break;
-
-	       case DestroyNotify:
-		    D("DestroyNotify\n");
-		    break;
-	       }
-	  }
      }
 }
 
@@ -457,7 +441,6 @@ static void check_pipe_fd_events(void)
      static NPWindow wintmp;
      int n;
   
-     Window oldwindow = WINDOW;
      D("Got pipe_fd data, old parent=%x pipe_fd=%d\n", WINDOW, pipe_fd);
   
      n = read(pipe_fd, ((char *)& wintmp),  sizeof(wintmp));
@@ -481,14 +464,6 @@ static void check_pipe_fd_events(void)
   
      D("Got pipe_fd data, new parent=%x\n", WINDOW);
   
-     if (WINDOW && WINDOW != oldwindow && display)
-     {
-	  XSelectInput(display, WINDOW, 
-		       SubstructureNotifyMask |
-		       SubstructureRedirectMask);
-	  XSync(display, False);
-     }
-  
      if (victim)
      {
 	  /* The window has been resized. */
@@ -631,11 +606,7 @@ int main(int argc, char **argv)
 	  {
                /* Has to be done before forking */
 	       save_initial_windows();
-	       XSelectInput(display, WINDOW,
-			    SubstructureNotifyMask |
-			    SubstructureRedirectMask);
-	       XSelectInput(display, wattr.root,
-			    SubstructureNotifyMask);
+	       XSelectInput(display, wattr.root, SubstructureNotifyMask);
 	       XSync(display, False);
 	  }
 
@@ -644,7 +615,6 @@ int main(int argc, char **argv)
       
 	  if (!pid)
 	  {
-	       XSelectInput(display, WINDOW, 0);
 	       XSelectInput(display, wattr.root, 0);
 	       D("Running %s\n", command);
 	       run_app(argv);
