@@ -236,11 +236,13 @@ static int inpath(char *path, char *file)
      int count = 1;
 
      for (i = strlen(path)-1; i > 0; i--)
+     {
 	  if (path[i] == ':')
 	  {
 	       path[i] = 0;
 	       count++;
 	  }
+     }
 
      for (i = 0; i < count; i++)
      {
@@ -908,6 +910,9 @@ NPError NPP_GetValue(void *instance, NPPVariable variable, void *value)
 		   " <tr><td>Configuration file:</td><td>%s</td></tr> "
 		   " <tr><td>Helper binary:</td><td>%s</td></tr> "
 		   " <tr><td>Controller binary:</td><td>%s</td></tr> "
+#ifdef DEBUG
+		   " <tr><td>Debug file:</td><td><a href=\"file:///home/user/tmp/mozdebug\">$HOME/tmp/mozdebug</a></td></tr> "
+#endif
 		   " </table> "
 		   "<br clear=all>",
 		   config_fname ? config_fname : "Not found!",
@@ -1231,8 +1236,18 @@ NPError NPP_SetWindow(NPP instance, NPWindow* window)
 
      if (THIS->fd != -1)
      {
-	  D("Writing WIN to fd %d\n", THIS->fd);
+	  D("Writing WIN 0x%x to fd %d\n", window->window, THIS->fd);
 	  write(THIS->fd, (char *)window, sizeof(*window));
+
+	  XSetWindowAttributes attrib;
+	  attrib.override_redirect = True;
+	  XChangeWindowAttributes(THIS->display, (Window)THIS->windata.window,
+				  CWOverrideRedirect, &attrib);
+
+	  D("Resizing WIN 0x%x to %dx%d!?\n", THIS->windata.window,
+	    THIS->windata.width, THIS->windata.height);
+	  XResizeWindow(THIS->display, (Window)THIS->windata.window,
+			THIS->windata.width, THIS->windata.height);
      }
 
      /* In case Mozilla would call NPP_SetWindow() in a loop. */
