@@ -33,6 +33,29 @@
 /* Time to wait for a process to exit */
 #define KILL_TIMEOUT_USEC 100000
 
+/* Each handler has a list of mime types, and a list of commands. */
+#define MAX_NUM_HANDLERS 64
+#define MAX_NUM_TYPES_PER_HANDLER 32
+#define MAX_NUM_CMDS_PER_HANDLER 32
+
+/* Maximum size of a mime type line. */
+#define MAX_TYPE_SIZE 256
+
+/* Maximum size of a command line. */
+#define MAX_CMD_SIZE 512
+
+/* Maximum size of a swallow() window. */
+#define MAX_WINNAME_SIZE 128
+
+/* Maximum size of the buffer used for environment variables. */
+#define ENV_BUFFER_SIZE 16348
+
+#define LARGE_BUFFER_SIZE 16384
+#define LARGE_BUFFER_SIZE_STR "16384"
+
+#define SMALL_BUFFER_SIZE 128
+#define SMALL_BUFFER_SIZE_STR "128"
+
 /* Flags */
 #define H_LOOP 		0x1
 #define H_DAEMON 	0x2
